@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.003';
+$Time::C::VERSION = '0.004';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -369,7 +369,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -414,19 +414,33 @@ Creates a Time::C object for the specified time, or the current time if no C<$ye
 
 =over
 
-=item C<$year> is the year. If not specified, C<new()> will call C<now_utc()>.
+=item C<$year>
 
-=item C<$month> is the month. If not specified it defaults to C<1>.
+This is the year. If not specified, C<new()> will call C<now_utc()>.
 
-=item C<$day> is the day of the month. If not specified it defaults to C<1>.
+=item C<$month>
 
-=item C<$hour> is the hour. If not specified it defaults to C<0>.
+This is the month. If not specified it defaults to C<1>.
 
-=item C<$minute> is the minute. If not specified it defaults to C<0>.
+=item C<$day>
 
-=item C<$second> is the second. If not specified it defaults to C<0>.
+This is the day of the month. If not specified it defaults to C<1>.
 
-=item C<$tz> is the timezone specification such as C<Europe/Stockholm> or C<UTC>. If not specified it defaults to C<UTC>.
+=item C<$hour>
+
+This is the hour. If not specified it defaults to C<0>.
+
+=item C<$minute>
+
+This is the minute. If not specified it defaults to C<0>.
+
+=item C<$second>
+
+This is the second. If not specified it defaults to C<0>.
+
+=item C<$tz>
+
+This is the timezone specification such as C<Europe/Stockholm> or C<UTC>. If not specified it defaults to C<UTC>.
 
 =back
 
@@ -439,9 +453,13 @@ Creates a Time::C object for the specified C<$epoch> and optional C<$tz>.
 
 =over
 
-=item C<$epoch> is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
+=item C<$epoch>
 
-=item C<$tz> is the timezone specification, such as C<Europe/Stockholm> or C<UTC>. If not specified defaults to the timezone specified in C<$ENV{TZ}>, or C<UTC> if that is unspecified.
+This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
+
+=item C<$tz>
+
+This is the timezone specification, such as C<Europe/Stockholm> or C<UTC>. If not specified defaults to the timezone specified in C<$ENV{TZ}>, or C<UTC> if that is unspecified.
 
 =back
 
@@ -453,7 +471,9 @@ Creates a Time::C object for the specified C<$epoch>. The timezone will be C<UTC
 
 =over
 
-=item C<$epoch> is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
+=item C<$epoch>
+
+This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
 
 =back
 
@@ -477,7 +497,9 @@ Creates a Time::C object for the specified C<$epoch>. The timezone will be C<UTC
 
 =over
 
-=item C<$epoch> is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
+=item C<$epoch>
+
+This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
 
 =back
 
@@ -491,11 +513,17 @@ Creates a Time::C object for the specified C<$str>, using the optional C<$format
 
 =over
 
-=item C<$str> is the string that will be parsed by either L<Time::Piece/strptime> or L<Time::Moment/from_string>.
+=item C<$str>
 
-=item C<$format> is the format that L<Time::Piece/strptime> will be given, by default it is C<undef>. If it is not defined, C<Time::Moment/from_string> will be used instead.
+This is the string that will be parsed by either L<Time::Piece/strptime> or L<Time::Moment/from_string>.
 
-=item C<$expected_tz> if the parsed time contains a zone or offset that parses, and the offset matches the C<$expected_tz> offset, C<$expected_tz> will be set as the timezone. If it doesn't match, a generic timezone matching the offset will be set, such as C<UTC> for an offset of C<0>. This variable will also default to C<UTC>.
+=item C<$format>
+
+This is the format that L<Time::Piece/strptime> will be given, by default it is C<undef>. If it is not defined, L<Time::Moment/from_string> will be used instead.
+
+=item C<$expected_tz>
+
+If the parsed time contains a zone or offset that parses, and the offset matches the C<$expected_tz> offset, C<$expected_tz> will be set as the timezone. If it doesn't match, a generic timezone matching the offset will be set, such as C<UTC> for an offset of C<0>. This variable will also default to C<UTC>.
 
 =back
 
@@ -530,7 +558,7 @@ If the form C<< $t->tz($new_tz) >> is used, it instead changes the internal tz a
   $t->offset = $offset;
   $t->offset += 60;
 
-Returns or sets the current offset in minutes. If the offset is set, it tries to find a generic C<UTC+XX:XX> timezone that matches the offset and updates the C<tz> to this. If it fails, it dies with an error.
+Returns or sets the current offset in minutes. If the offset is set, it tries to find a generic C<Etc/GMT+X> or C<+XX:XX> timezone that matches the offset and updates the C<tz> to this. If it fails, it dies with an error.
 
 =head2 tm
 
@@ -546,7 +574,7 @@ Returns a Time::Moment object for the current epoch and offset. On setting, it c
   $t->string = $str;
   $t->string($format) = $str;
 
-Renders the current time to a string using the optional strftime C<$format>. If the C<$format> is not given it defaults to C<undef>. When setting this value, it tries to parse the string using the strptime C<$format> or L<Time::Moment/from_string> if no C<$format> was given or strptime fails. If the detected C<offset> matches the current C<tz>, that is kept, otherwise it will get changed to a generic C<tz> in the form of C<Etc/GMT+X> or C<+XX:XX>.
+Renders the current time to a string using the optional strftime C<$format>. If the C<$format> is not given it defaults to C<undef>. When setting this value, it tries to parse the string using L<Time::Piece/strptime> with the C<$format> or L<Time::Moment/from_string> if no C<$format> was given or strptime fails. If the detected C<offset> matches the current C<tz>, that is kept, otherwise it will get changed to a generic C<tz> in the form of C<Etc/GMT+X> or C<+XX:XX>.
 
 =head2 year
 
